package com.phlx.anchorcollect.data;


import androidx.annotation.NonNull;

import com.phlx.anchorcollect.data.http.HttpDataSource;
import com.phlx.anchorcollect.data.local.LocalDataSource;
import com.phlx.anchorcollect.entity.GenData;
import com.phlx.anchorcollect.entity.LoginData;
import com.phlx.anchorcollect.params.CollectResponse;

import java.util.Map;

import io.reactivex.Observable;
import me.goldze.mvvmhabit.base.BaseModel;
import retrofit2.http.FieldMap;

/**
 *
 */
public class Repository extends BaseModel implements HttpDataSource, LocalDataSource {
    private volatile static Repository INSTANCE = null;
    private final HttpDataSource mHttpDataSource;

    private final LocalDataSource mLocalDataSource;

    private Repository(@NonNull HttpDataSource httpDataSource,
                       @NonNull LocalDataSource localDataSource) {
        this.mHttpDataSource = httpDataSource;
        this.mLocalDataSource = localDataSource;
    }

    public static Repository getInstance(HttpDataSource httpDataSource,
                                         LocalDataSource localDataSource) {
        if (INSTANCE == null) {
            synchronized (Repository.class) {
                if (INSTANCE == null) {
                    INSTANCE = new Repository(httpDataSource, localDataSource);
                }
            }
        }
        return INSTANCE;
    }

    public static void destroyInstance() {
        INSTANCE = null;
    }


    @Override
    public Observable<CollectResponse<LoginData>> loginPost(@FieldMap Map<String,String> map) {
        return mHttpDataSource.loginPost(map);
    }

    @Override
    public Observable<CollectResponse<GenData>> genGet() {
        return mHttpDataSource.genGet();
    }



    /****************************************************************************/

    @Override
    public void saveUserName(String userName) {
        mLocalDataSource.saveUserName(userName);
    }

    @Override
    public void savePassword(String password) {
        mLocalDataSource.savePassword(password);
    }

    @Override
    public void savePhone(String phone) {
        mLocalDataSource.savePhone(phone);
    }

    @Override
    public void saveEmail(String email) {
        mLocalDataSource.saveEmail(email);
    }

    @Override
    public void saveFrequencyConfig(String frequencyConfig) {
        mLocalDataSource.saveFrequencyConfig(frequencyConfig);
    }

    @Override
    public void saveToken(String token) {
        mLocalDataSource.saveToken(token);
    }

    @Override
    public String getUserName() {
        return mLocalDataSource.getUserName();
    }

    @Override
    public String getPassword() {
        return mLocalDataSource.getPassword();
    }

    @Override
    public String getPhone() {
        return mLocalDataSource.getPhone();
    }

    @Override
    public String getEmail() {
        return mLocalDataSource.getEmail();
    }

    @Override
    public String getFrequencyConfig() {
        return mLocalDataSource.getFrequencyConfig();
    }

    @Override
    public String getToken() {
        return mLocalDataSource.getToken();
    }


}
