package com.phlx.anchorcollect.ui.main;

import android.os.Bundle;

import androidx.fragment.app.FragmentTransaction;
import androidx.lifecycle.Observer;
import androidx.lifecycle.ViewModelProviders;

import com.phlx.anchorcollect.BR;
import com.phlx.anchorcollect.Configs;
import com.phlx.anchorcollect.R;
import com.phlx.anchorcollect.data.VMFactory;
import com.phlx.anchorcollect.databinding.ActivityMainBinding;
import com.phlx.anchorcollect.ui.base.BaseActivity;
import com.phlx.anchorcollect.ui.fragment.BasicsCollectFragment;
import com.phlx.anchorcollect.ui.fragment.CollectFragment;
import com.phlx.anchorcollect.ui.fragment.CollectListFragment;

public class MainActivity extends BaseActivity<ActivityMainBinding, MainVM> {

    private String collectType = "";

    private FragmentTransaction transaction;

    private BasicsCollectFragment _basicsCollectFragment;
    private CollectListFragment _collectListFragment;

    @Override
    public int initContentView(Bundle savedInstanceState) {
        return R.layout.activity_main;
    }

    @Override
    public int initVariableId() {
        return BR.viewModel;
    }

    @Override
    public void initParam() {
        super.initParam();
        Bundle mBundle = getIntent().getExtras();
        if (mBundle != null) {
            collectType = mBundle.getString("COLLECT_TYPT");
        }
    }

    @Override
    public MainVM initViewModel() {
        VMFactory factory = VMFactory.getInstance(getApplication());
        return ViewModelProviders.of(this, factory).get(MainVM.class);
    }

    @Override
    public void initData() {
        super.initData();

        viewModel.init();

        //初始化标题
//        viewModel.initToolbar(getTitleName());
        //初始化Fragment
        initFragment();
    }

    @Override
    public void initViewObservable() {
        super.initViewObservable();

        viewModel.onTabClickEvent.observe(this, new Observer<Integer>() {
            @Override
            public void onChanged(Integer integer) {
                labelSwitching(integer);
            }
        });
    }

    private void initFragment() {

        transaction = getSupportFragmentManager().beginTransaction();

        _basicsCollectFragment = BasicsCollectFragment.newInstance();
        _collectListFragment = CollectListFragment.newInstance(collectType);
        transaction.add(R.id.frameLayout, _basicsCollectFragment);
        transaction.add(R.id.frameLayout, _collectListFragment);
        transaction.commit();
        labelSwitching(0);
    }

    public void labelSwitching(int position) {

        transaction = getSupportFragmentManager().beginTransaction();
        transaction.hide(_basicsCollectFragment);
        transaction.hide(_collectListFragment);
        binding.tvTab0.setTextColor(getResources().getColor(R.color.color_font_non_focus));
        binding.tvTab1.setTextColor(getResources().getColor(R.color.color_font_non_focus));
        switch (position) {
            case 0:
                transaction.show(_basicsCollectFragment);
                binding.tvTab0.setTextColor(getResources().getColor(R.color.colorPrimary));
                break;
            case 1:
                transaction.show(_collectListFragment);
                binding.tvTab1.setTextColor(getResources().getColor(R.color.colorPrimary));
                break;
        }

        transaction.commit();
    }



}
