package com.phlx.anchorcollect.ui.setting;

import android.Manifest;
import android.bluetooth.BluetoothAdapter;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;

import androidx.lifecycle.Observer;
import androidx.lifecycle.ViewModelProviders;

import com.phlx.anchorcollect.App;
import com.phlx.anchorcollect.BR;
import com.phlx.anchorcollect.R;
import com.phlx.anchorcollect.data.VMFactory;
import com.phlx.anchorcollect.databinding.ActivityBtSettingBinding;
import com.phlx.anchorcollect.rfid.NetModuleManager;
import com.phlx.anchorcollect.ui.base.BaseActivity;
import com.phlx.anchorcollect.util.ConstantUtil;
import com.tbruyelle.rxpermissions2.RxPermissions;

import java.util.ArrayList;
import java.util.List;

import cn.wandersnail.commons.util.ToastUtils;
import io.reactivex.functions.Consumer;

public class BtSettingActivity extends BaseActivity<ActivityBtSettingBinding, BtSettingVM> {
    @Override
    public int initContentView(Bundle savedInstanceState) {
        return R.layout.activity_bt_setting;
    }

    @Override
    public int initVariableId() {
        return BR.viewModel;
    }

    @Override
    public void initParam() {
        super.initParam();
    }

    @Override
    public BtSettingVM initViewModel() {
        VMFactory factory = VMFactory.getInstance(getApplication());
        return ViewModelProviders.of(this, factory).get(BtSettingVM.class);
    }

    @Override
    public void initData() {
        super.initData();

        initNet();
        viewModel.initBt(this);
    }

    @Override
    public void initViewObservable() {
        super.initViewObservable();

        viewModel.btRequestEvent.observe(this, new Observer<Integer>() {
            @Override
            public void onChanged(Integer integer) {
                startActivity(new Intent(BluetoothAdapter.ACTION_REQUEST_ENABLE));
            }
        });

        viewModel.btParamEvent.observe(this, new Observer<Boolean>() {
            @Override
            public void onChanged(Boolean aBoolean) {
                initialize();
            }
        });
    }

    private void initNet() {

        App.getInstance().getLinkage().setRFModuleType(2);
        int hy = NetModuleManager.openCom();
        if (hy == 0) {
            new Handler().postDelayed(() -> new Thread(() -> {
                App.getInstance().getLinkage().setRFConnectMode(1);
                App.getInstance().getLinkage().stopInventory();
                if (NetModuleManager.getBoardSerialNumber() == 0) {
                    if (NetModuleManager.getBoardSoftVersion() == 0) {
//                        if (NetModuleManager.getSoftwareVersion() == 0)
//                            if (NetModuleManager.getHardwareVersion() == 0)
                                ToastUtils.showShort("硬件版本：" + ConstantUtil.RM70XX_SERIAL_VERSION + "，软件版本：" + ConstantUtil.RM70XX_VERSION);
//                                ToastUtils.showShort("硬件版本：" + ConstantUtil.VERSION + "，软件版本：" + ConstantUtil.SERIAL_VERSION);
                    } else {
                        ToastUtils.showShort("软件版本获取失败");
                    }
                } else {
                    ToastUtils.showShort("硬件版本获取失败");
                }
            }).start(), 100);
        } else {
            ToastUtils.showShort("网口打开失败:" + hy);
        }

    }

    private void initialize() {

        //请求打开定位权限
        RxPermissions rxPermissions = new RxPermissions(this);
        rxPermissions.request(getNeedPermissions().get(0))
                .subscribe(new Consumer<Boolean>() {
                    @Override
                    public void accept(Boolean aBoolean) throws Exception {
                        if (aBoolean) {
//                            ToastUtils.showShort("权限已经打开");
                        } else {
                            ToastUtils.showShort("权限被拒绝");
                        }
                    }
                });

    }

    //需要进行检测的权限
    private List<String> getNeedPermissions() {
        List<String> list = new ArrayList<>();
        if (getApplicationInfo().targetSdkVersion >= 29) {//target sdk版本在29以上的需要精确定位权限才能搜索到蓝牙设备
            list.add(Manifest.permission.ACCESS_FINE_LOCATION);
        } else {
            list.add(Manifest.permission.ACCESS_COARSE_LOCATION);
        }
        //Android 12需要
//        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.S) {
//            list.add(Manifest.permission.BLUETOOTH_SCAN);
//            list.add(Manifest.permission.BLUETOOTH_CONNECT);
//        }
        return list;
    }
}
