package com.phlx.anchorcollect.ui.setting;

import android.Manifest;
import android.annotation.SuppressLint;
import android.app.Activity;
import android.app.ActivityManager;
import android.app.Application;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.content.Context;
import android.content.Intent;
import android.media.AudioManager;
import android.media.SoundPool;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.text.TextUtils;
import android.util.Log;
import android.util.SparseIntArray;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableArrayList;
import androidx.databinding.ObservableList;
import androidx.lifecycle.LiveData;

import com.phlx.anchorcollect.App;
import com.phlx.anchorcollect.BR;
import com.phlx.anchorcollect.R;
import com.phlx.anchorcollect.ble.BleDialog;
import com.phlx.anchorcollect.ble.BleService;
import com.phlx.anchorcollect.ble.BluetoothEntity;
import com.phlx.anchorcollect.bt.BtService;
import com.phlx.anchorcollect.data.Repository;
import com.phlx.anchorcollect.rfid.InventoryManger;
import com.phlx.anchorcollect.util.TextUtil;
import com.tbruyelle.rxpermissions2.RxPermissions;
import com.uhf.structures.InventoryData;
import com.uhf.structures.InventoryParams;
import com.uhf.structures.OnInventoryListener;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import cn.wandersnail.ble.Device;
import cn.wandersnail.bluetooth.BTManager;
import cn.wandersnail.bluetooth.DiscoveryListener;
import cn.wandersnail.commons.util.ToastUtils;
import io.reactivex.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.bus.event.SingleLiveEvent;
import me.tatarka.bindingcollectionadapter2.ItemBinding;

public class BtSettingVM extends BaseViewModel<Repository> implements DiscoveryListener, OnInventoryListener {

    private SoundPool soundPool;//盘点到标签时的提示音
    private SparseIntArray musicId;
    private static Map<String, Integer> map;//去重
    private ArrayList<BluetoothEntity> mList;

    private boolean isInventory = false;

    //给RecyclerView添加ObservableList
    public ObservableList<BLEItem> observableList = new ObservableArrayList<>();
    //给RecyclerView添加ItemBinding
    public ItemBinding<BLEItem> itemBinding = ItemBinding.of(BR.viewModel, R.layout.item_ble);

    private Device curDevice;


    //选中的蓝牙设备信息
    public static BluetoothEntity bluetoothEntity;

    //当前蓝牙搜索集合
    private List<BluetoothEntity> bluetoothList;

    public SingleLiveEvent<Integer> btRequestEvent = new SingleLiveEvent<>();
    public SingleLiveEvent<Boolean> btParamEvent = new SingleLiveEvent<>();

    public BtSettingVM(@NonNull Application application, Repository model) {
        super(application, model);

        initInventory();
        //设置盘点数据监听
        App.getInstance().getLinkage().setOnInventoryListener(this);
    }

    private void initInventory() {

        map = new HashMap<>();
        mList = new ArrayList<>();
        soundPool = new SoundPool(2, AudioManager.STREAM_MUSIC, 5);
        musicId = new SparseIntArray();
        musicId.put(1, soundPool.load(getApplication(), R.raw.readcard, 1));
        musicId.put(2, soundPool.load(getApplication(), R.raw.failure, 1));

        //设置盘点内容：Epc + Tid
        InventoryParams inventoryParams = new InventoryParams();
        inventoryParams.address = 0;
        inventoryParams.inventoryArea = 1;
        inventoryParams.len = 6;
        App.getInstance().getLinkage().Radio_SetInventoryParams(inventoryParams);
        int filterStatus = setInventoryFilter();
        Log.e("filterStatus:", "" + filterStatus);
    }

    private int setInventoryFilter() {
        int tsh = 0;
        int maxRepeat = 1;
        int cacheTime = 0;
        int maxMonitorTagInRangeTimeMs = 0;
        int maxMonitorTagOutRangeTimeMs = 0;
        int filterMode = 0;
        maxRepeat |= (filterMode << 14);
        return InventoryManger.from().setInventoryFilter(tsh, maxRepeat, cacheTime, maxMonitorTagInRangeTimeMs, maxMonitorTagOutRangeTimeMs);
    }

    public void initBt(Context context) {

        bluetoothList = new ArrayList<>();
        BTManager.isDebugMode = true;
        BTManager.getInstance().addDiscoveryListener(this);
        btParamEvent.call();
    }

    public BindingCommand OnRefreshClickCommand = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            BTManager.getInstance().stopDiscovery();
            doStartDiscovery();
        }
    });

    private void doStartDiscovery() {
        observableList.clear();
        bluetoothList.clear();
        BTManager.getInstance().startDiscovery();
    }

    public BindingCommand OnStopClickCommand = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            BTManager.getInstance().stopDiscovery();
        }
    });

    public BindingCommand OnConnectionClickCommand = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            mList.clear();
            map.clear();
            observableList.clear();
            if (isInventory)
                App.getInstance().getLinkage().stopInventory();
            else
                App.getInstance().getLinkage().startInventory(1, 0);
            isInventory = !isInventory;
        }
    });

    public BindingCommand OnDisconnectionClickCommand = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            //断开指定连接
            stopBtService();
            if (bluetoothEntity != null)
                BTManager.getInstance().disconnectConnection(bluetoothEntity.getBluetoothDevice());
        }
    });

    public void itemOnClick(BluetoothEntity btEntity) {
        BTManager.getInstance().stopDiscovery();
        stopBtService();
        bluetoothEntity = btEntity;

        Intent intent = new Intent(getApplication(), BtService.class);
        intent.putExtra("device", bluetoothEntity.getBluetoothDevice());
        if (!isServiceRunning(getApplication()))
            getApplication().startService(intent);
    }


    @Override
    public void onDiscoveryStart() {

    }

    @Override
    public void onDiscoveryStop() {

    }

    @Override
    public void onDeviceFound(@NonNull BluetoothDevice device, int rssi) {
        if (!TextUtils.isEmpty(device.getName())) {
            BluetoothEntity entity = new BluetoothEntity();
            entity.setName(device.getName());
            entity.setAddress(device.getAddress());
            entity.setRssi(rssi);
            entity.setBluetoothDevice(device);
            if (!bluetoothList.contains(entity)) {
                bluetoothList.add(entity);
                BLEItem bleItem = new BLEItem(this, entity);
                observableList.add(bleItem);
            }
        }
    }

    @Override
    public void onDiscoveryError(int errorCode, @NonNull String errorMsg) {
        switch (errorCode) {
            case DiscoveryListener.ERROR_LACK_LOCATION_PERMISSION://缺少定位权限
                ToastUtils.showShort("搜索出错：缺少定位权限" + errorCode);
                break;
            case DiscoveryListener.ERROR_LOCATION_SERVICE_CLOSED://位置服务未开启
                ToastUtils.showShort("搜索出错：位置服务未开启" + errorCode);
                break;
            case DiscoveryListener.ERROR_LACK_SCAN_PERMISSION://缺少搜索权限
                ToastUtils.showShort("搜索出错：缺少搜索权限" + errorCode);
                break;
            case DiscoveryListener.ERROR_SCAN_FAILED://搜索失败
                ToastUtils.showShort("搜索出错：" + errorCode);
                break;
        }
    }

    @Override
    public void onPause() {
        super.onPause();
        if (BTManager.getInstance().isInitialized()) {
            BTManager.getInstance().stopDiscovery();
        }
    }

    @Override
    public void onResume() {
        super.onResume();
        Log.d("Main", "onResume");
        if (BTManager.getInstance().isInitialized()) {
            if (BTManager.getInstance().isBluetoothOn()) {
//                doStartDiscovery();
            } else {
                //未开启蓝牙
                btRequestEvent.call();
            }
        }
    }

    /**
     * 判断服务是否在运行中
     *
     * @param context 即为Context对象
     * @return 是否在运行中
     */
    private boolean isServiceRunning(Context context) {
        if (context != null) {
            ActivityManager activityManager
                    = (ActivityManager) context.getSystemService(Context.ACTIVITY_SERVICE);
            ArrayList<ActivityManager.RunningServiceInfo> runningServiceInfoList
                    =
                    (ArrayList<ActivityManager.RunningServiceInfo>) activityManager.getRunningServices(100);
            for (ActivityManager.RunningServiceInfo runningServiceInfo : runningServiceInfoList) {
                if ("BtService".equals(runningServiceInfo.service.getClassName())) {
                    return true;
                }
            }
        } else {
            return false;
        }
        return false;
    }


    public void stopBtService() {
        if (isServiceRunning(getApplication())) {
            Intent intent = new Intent(getApplication(), BtService.class);
            getApplication().stopService(intent);
        }
    }

    @Override
    public void getInventoryData(InventoryData inventoryData) {
        if (inventoryData != null) {
            Message messenger = handler.obtainMessage();
            messenger.what = 0x333;
            messenger.obj = inventoryData;
            handler.sendMessage(messenger);
        }
    }

    @SuppressLint("HandlerLeak")
    private Handler handler = new Handler() {
        @Override
        public void handleMessage(Message msg) {
            if (msg.what == 0x333) {
                InventoryData inventoryData = (InventoryData) msg.obj;
                String epc = "";
                String tid_user = "";
                String rss = "";
                String port = "";
                if (inventoryData.getDataLength() > 0) {
                    tid_user = TextUtil.byteToHexString(inventoryData.getData(), inventoryData.getDataLength());
                }
                if (inventoryData.getEpcLength() > 0) {
                    epc = TextUtil.byteToHexString(inventoryData.getEPC_Data(), inventoryData.getEpcLength());
                    rss = String.valueOf(inventoryData.getRSSI());
                }
                String tag = epc + tid_user;
                if (!map.containsKey(tag)) {
                    BluetoothEntity entity = new BluetoothEntity();
                    entity.setName(tag);
                    entity.setAddress("");
                    BLEItem bleItem = new BLEItem(BtSettingVM.this, entity);
                    mList.add(entity);
                    observableList.add(bleItem);
                    soundPool.play(musicId.get(1), 1, 1, 0, 0, 1);
                    map.put(tag, mList.size() - 1);
                }
            }
        }
    };
}
