package com.phlx.anchorcollect.ui.splash;

import android.app.Application;

import androidx.annotation.NonNull;

import com.google.gson.Gson;
import com.phlx.anchorcollect.data.Repository;
import com.phlx.anchorcollect.db.DbUtil;
import com.phlx.anchorcollect.db.interf.DbIDUCallBack;
import com.phlx.anchorcollect.entity.GenData;
import com.phlx.anchorcollect.entity.GenTable;
import com.phlx.anchorcollect.entity.GenTableColumn;
import com.phlx.anchorcollect.params.CollectResponse;
import com.phlx.anchorcollect.params.PostParams;
import com.phlx.anchorcollect.ui.base.MainBarVM;
import com.phlx.anchorcollect.ui.home.HomeActivity;
import com.phlx.anchorcollect.ui.main.MainActivity;

import io.reactivex.functions.Consumer;
import me.goldze.mvvmhabit.bus.event.SingleLiveEvent;
import me.goldze.mvvmhabit.http.ResponseThrowable;
import me.goldze.mvvmhabit.utils.KLog;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.SPUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;
import okhttp3.MediaType;
import okhttp3.RequestBody;

public class SplashVM extends MainBarVM<Repository> {

    public SingleLiveEvent<String> errorEvent = new SingleLiveEvent<>();

    private int labelPageIndex = 1;
    private int unitPageIndex = 0;

    public SplashVM(@NonNull Application application, Repository repository) {
        super(application, repository);

    }

    public void requestGen() {

        PostParams postParams = new PostParams();
        RequestBody body = RequestBody.create(MediaType.parse("application/json; charset=utf-8"), new Gson().toJson(postParams));
        KLog.e("Gen", postParams.toString());
        addSubscribe(model.genGet()
                .compose(RxUtils.bindToLifecycle(getLifecycleProvider()))
                .compose(RxUtils.schedulersTransformer())
                .compose(RxUtils.exceptionTransformer())
                .doOnSubscribe(disposable -> {
                })
                .subscribe((Consumer<CollectResponse<GenData>>) response -> {

                    if (response.getCode() == 0) {

                        //清除之前的页面配置
                        DbUtil.getInstance().deleteAll(GenTable.class);
                        DbUtil.getInstance().deleteAll(GenTableColumn.class);

                        if (response.getData().getGenTableColumns() != null && response.getData().getGenTables() != null) {
                            KLog.e(response.getData().getGenTables().size() + "|" + response.getData().getGenTableColumns().size());
                            DbUtil.getInstance().setDbIDUCallBack(new DbIDUCallBack() {
                                @Override
                                public void onNotification(boolean result) {
                                    if (result) {
                                        DbUtil.getInstance().setDbIDUCallBack(new DbIDUCallBack() {
                                            @Override
                                            public void onNotification(boolean result) {
                                                if (result) {
                                                    dismissDialog();
                                                    ToastUtils.showShort("页面配置详情数据更新完成！");
                                                    SPUtils.getInstance().put("isFirst", false);
                                                    startActivity(MainActivity.class);
                                                    finish();
                                                } else {
                                                    errorEvent.setValue("保存页面配置详情数据失败");
                                                }
                                            }
                                        }).insertAsyncBatch(GenTableColumn.class, response.getData().getGenTableColumns());
                                    } else {
                                        errorEvent.setValue("保存页面配置数据失败");
                                    }
                                }
                            }).insertAsyncBatch(GenTable.class, response.getData().getGenTables());
                        } else {
                            dismissDialog();
                        }
                    } else {
                        errorEvent.setValue("同步页面配置数据错误 :" + response.getMsg());
                    }
                }, (Consumer<ResponseThrowable>) throwable -> {
                    dismissDialog();
                    KLog.e(throwable.message);
                    errorEvent.setValue("同步页面配置数据失败");
                })
        );
    }


}
